# conan_unified_api
Compatibility layer for Conan 1 and 2 for Python.


## Supported Conan versions
 
* 1.X: from 1.48 to latest
* 2.X from 2.0.14 to 2.5

## Test matrix

Tested Conan 1 versions: 1.48, 1.59.0 and latest
Tested Conan 2 versions: all minor versions until latest

 **Python/OS.** | **3.8** | **3.9** | **3.10** | **3.11** | **3.12** 
----------------|---------|---------|----------|----------|----------
 **u20**        | conan1  |conan1   |conan1&2  |conan1    |          
 **u22**        |         |         |          |          |conan1&2
 **win**        |         |         |          |conan1    |conan2
